==> kdiagram-2.6.0.tar.xz: kdiagram-2.6.0/src/KChart/Cartesian/DiagramFlavors/KChartStackedPlotter_p.h <==
/* -*- Mode: C++ -*-
   KChart - a multi-platform charting engine
   */

/****************************************************************************
 ** Copyright (C) 2005-2007 Klarälvdalens Datakonsult AB.  All rights reserved.
 **
 ** This file is part of the KD Chart library.
 **
 ** This file may be used under the terms of the GNU General Public
 ** License versions 2.0 or 3.0 as published by the Free Software
 ** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
 ** included in the packaging of this file.  Alternatively you may (at
 ** your option) use any later version of the GNU General Public
 ** License if such license has been publicly approved by
 ** Klarälvdalens Datakonsult AB (or its successors, if any).
 **
 ** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
 ** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
 ** A PARTICULAR PURPOSE. Klarälvdalens Datakonsult AB reserves all rights
 ** not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 **********************************************************************/

#ifndef KCHARTSTACKEDPLOTTER_P_H
#define KCHARTSTACKEDPLOTTER_P_H

#include "KChartPlotter_p.h"

namespace KChart {

    class StackedPlotter : public Plotter::PlotterType
    {
    public:
        explicit StackedPlotter( Plotter* );
        virtual ~StackedPlotter() {}
        virtual Plotter::PlotType type() const;
        virtual const QPair< QPointF,  QPointF > calculateDataBoundaries() const;
        virtual void paint( PaintContext* ctx );
        double interpolateMissingValue( const CartesianDiagramDataCompressor::CachePosition& pos ) const;
    };
}

#endif

==> kdiagram_2.6.3.orig.tar.xz: kdiagram-2.6.3/src/KChart/Cartesian/DiagramFlavors/KChartStackedPlotter_p.h <==
/* -*- Mode: C++ -*-
   KChart - a multi-platform charting engine
   */

/****************************************************************************
 ** Copyright (C) 2005-2007 Klarälvdalens Datakonsult AB.  All rights reserved.
 **
 ** This file is part of the KD Chart library.
 **
 ** This file may be used under the terms of the GNU General Public
 ** License versions 2.0 or 3.0 as published by the Free Software
 ** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
 ** included in the packaging of this file.  Alternatively you may (at
 ** your option) use any later version of the GNU General Public
 ** License if such license has been publicly approved by
 ** Klarälvdalens Datakonsult AB (or its successors, if any).
 **
 ** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
 ** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
 ** A PARTICULAR PURPOSE. Klarälvdalens Datakonsult AB reserves all rights
 ** not expressly granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 **********************************************************************/

#ifndef KCHARTSTACKEDPLOTTER_P_H
#define KCHARTSTACKEDPLOTTER_P_H

#include "KChartPlotter_p.h"

namespace KChart {

    class StackedPlotter : public Plotter::PlotterType
    {
    public:
        explicit StackedPlotter( Plotter* );
        virtual ~StackedPlotter() {}
        Plotter::PlotType type() const Q_DECL_OVERRIDE;
        const QPair< QPointF,  QPointF > calculateDataBoundaries() const Q_DECL_OVERRIDE;
        void paint( PaintContext* ctx ) Q_DECL_OVERRIDE;
        double interpolateMissingValue( const CartesianDiagramDataCompressor::CachePosition& pos ) const;
    };
}

#endif
